Skip to main content

pixi-cli✨

pixi-cli is a command-line tool for image conversion and basic image processing tasks.

Features

  • Crop images
  • Adjust exposure
  • Adjust saturation
  • Adjust contrast
  • Adjust sharpness
  • Apply box blur
  • Apply Gaussian blur
  • Reduce noise
  • Detect edges
  • Convert images to black and white
  • Invert colors
  • Rotate images (90, 180, 270 degrees)
  • Flip images (horizontally and vertically)
  • Create thumbnails
  • Compress images
  • Get image size
  • Fetch image metadata
  • Convert between image formats (e.g., jpg, png, bmp, gif, tiff, svg)

Installation

You can either download Pixi-CLI through PyPI (recommended) or you can download the executable.

Installing via PyPI

  1. Ensure you have Python and pip installed on your machine.
  2. Install pixi-cli using pip:
pip install pixi-cli

Downloading the Executable

Download the executable from the latest release of pixi from the Releases page and run it directly.

Usage

Basic Usage

  1. Open a terminal or Command Prompt.
  2. Use the command line to perform various image processing tasks.

Examples

  1. Get Image Size:

    pixi /path/to/input.jpg --size
    
  2. Get Image Metadata:

    pixi  /path/to/input.jpg --metadata
    
  3. Crop Image:

    pixi /path/to/input.jpg --output_path /path/to/output.jpg --crop 50 50 200 200
    
  4. Adjust Exposure:

    pixi /path/to/input.jpg --output_path /path/to/output.jpg --exposure 1.2
    
  5. Apply Gaussian Blur:

    pixi /path/to/input.jpg --output_path /path/to/output.jpg --gaussian_blur 2.0
    
  6. Convert to Black and White:

    pixi /path/to/input.jpg --output_path /path/to/output.jpg --bw
    
  7. Rotate Image 90 Degrees:

    pixi /path/to/input.jpg --rotate90
    
  8. Convert Image Format:

    pixi /path/to/input.jpg --convert png
    

Full Command-Line Arguments

  • image_path: Path to the input image (required).
  • --output_path: Path to save the processed image (required for processing operations).
  • --crop LEFT TOP RIGHT BOTTOM: Crop the image to the specified box.
  • --exposure EV: Adjust the exposure by a certain number of exposure values.
  • --saturation LEVEL: Adjust saturation level.
  • --contrast LEVEL: Adjust the contrast by the given factor.
  • --sharpness FACTOR: Adjust the sharpness by the given factor.
  • --box_blur RADIUS: Apply box blur with the specified radius.
  • --gaussian_blur RADIUS: Apply Gaussian blur with the specified radius.
  • --reduce_noise: Reduce noise in the image.
  • --edge_detect: Detect edges in the image
  • --bw: Convert the image to black and white.
  • --invert: Invert the colors of the image.
  • --thumbnail width height: Create a thumbnail of the specified size.
  • --compression QUALITY: Compress the image to the specified quality (0-100).
  • --size: Get the size of the image.
  • --metadata: Fetch the metadata of the image.
  • --rotate90: Rotate the image 90 degrees clockwise.
  • --rotate180: Rotate the image 180 degrees.
  • --rotate270: Rotate the image 270 degrees clockwise.
  • --flip_horiz: Flip the image horizontally.
  • --flip_vert: Flip the image vertically.
  • --convert FORMAT: Convert the image to the specified format.

Getting help

For more options and detailed usage, run:

pixi --help

Contributing

Contributions are welcome! Please fork the repository and submit pull requests.

License

This project is licensed under the MIT License - see the LICENSE file for details.

Metadata

Release files for pixi-cli 0.2.1

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for pixi-cli 0.2.1
File Size Uploaded
pixi-cli-0.2.1.tar.gz 6.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for pixi-cli 0.2.1
File Interpreter ABI Platform
pixi_cli-0.2.1-py3-none-any.whl Python 3 none any Details

Total release size: 12.5 kB

Release files / pixi-cli-0.2.1.tar.gz

Download URL pixi-cli-0.2.1.tar.gz
Size 6.0 kB
Tags Source
SHA-256 checksum
How to use checksums
b29d4903176c136cae8caabb9e37f3347d67233a7bc49176bd6832f5fbcf935e
BLAKE2b-256 checksum
How to use checksums
3a0bfd53837911fc1c253e3627b3ef0cee488867775f2feba4d79f070a550c00
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.10.7

Release files / pixi_cli-0.2.1-py3-none-any.whl

Download URL pixi_cli-0.2.1-py3-none-any.whl
Size 6.5 kB
Tags Python 3
SHA-256 checksum
How to use checksums
9e5d28e81ad0eb11a26b2d2dde04cea58aad116f891b4628347d931bf92f9ef8
BLAKE2b-256 checksum
How to use checksums
d08125a83c5580447ef9ddbb051b4d1fae0ec6a65b94428ee2df8d0b5923da2d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.10.7

Release history Release notifications | RSS feed

This release

0.2.1 This release

2 release files

0.2.0

2 release files

0.1.2

2 release files

0.1.1

2 release files

0.1.0

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page